@@ -1,18 +1,18 @@
 from .basic import (
-    get_astrbot_root,
     check_astrbot_root,
     check_dashboard,
+    get_astrbot_root,
 )
-from .plugin import get_git_repo, manage_plugin, build_plug_list, PluginStatus
+from .plugin import PluginStatus, build_plug_list, get_git_repo, manage_plugin
 from .version_comparator import VersionComparator
 
 __all__ = [
-    "get_astrbot_root",
+    "PluginStatus",
+    "VersionComparator",
+    "build_plug_list",
     "check_astrbot_root",
     "check_dashboard",
+    "get_astrbot_root",
     "get_git_repo",
     "manage_plugin",
-    "build_plug_list",
-    "VersionComparator",
-    "PluginStatus",
 ]
