@@ -1,6 +1,7 @@
 import json
 import os
 from typing import TypeVar
+
 from astrbot.core.utils.astrbot_path import get_astrbot_data_path
 
 _VT = TypeVar("_VT")
@@ -16,7 +17,7 @@ class SharedPreferences:
     def _load_preferences(self):
         if os.path.exists(self.path):
             try:
-                with open(self.path, "r") as f:
+                with open(self.path) as f:
                     return json.load(f)
             except json.JSONDecodeError:
                 os.remove(self.path)
