@@ -1,10 +1,13 @@
 from __future__ import annotations
+
 import abc
-from typing import List, AsyncGenerator, Union, Type
+from collections.abc import AsyncGenerator
+
 from astrbot.core.platform.astr_message_event import AstrMessageEvent
+
 from .context import PipelineContext
 
-registered_stages: List[Type[Stage]] = []  # 维护了所有已注册的 Stage 实现类类型
+registered_stages: list[type[Stage]] = []  # 维护了所有已注册的 Stage 实现类类型
 
 
 def register_stage(cls):
@@ -22,18 +25,21 @@ class Stage(abc.ABC):
 
         Args:
             ctx (PipelineContext): 消息管道上下文对象, 包括配置和插件管理器
+
         """
         raise NotImplementedError
 
     @abc.abstractmethod
     async def process(
-        self, event: AstrMessageEvent
-    ) -> Union[None, AsyncGenerator[None, None]]:
+        self,
+        event: AstrMessageEvent,
+    ) -> None | AsyncGenerator[None, None]:
         """处理事件
 
         Args:
             event (AstrMessageEvent): 事件对象，包含事件的相关信息
         Returns:
             Union[None, AsyncGenerator[None, None]]: 处理结果，可能是 None 或者异步生成器, 如果为 None 则表示不需要继续处理, 如果为异步生成器则表示需要继续处理(进入下一个阶段)
+
         """
         raise NotImplementedError
