@@ -37,7 +37,10 @@ else:
 @register_platform_adapter("telegram", "telegram 适配器")
 class TelegramPlatformAdapter(Platform):
     def __init__(
-        self, platform_config: dict, platform_settings: dict, event_queue: asyncio.Queue
+        self,
+        platform_config: dict,
+        platform_settings: dict,
+        event_queue: asyncio.Queue,
     ) -> None:
         super().__init__(event_queue)
         self.config = platform_config
@@ -45,13 +48,15 @@ class TelegramPlatformAdapter(Platform):
         self.client_self_id = uuid.uuid4().hex[:8]
 
         base_url = self.config.get(
-            "telegram_api_base_url", "https://api.telegram.org/bot"
+            "telegram_api_base_url",
+            "https://api.telegram.org/bot",
         )
         if not base_url:
             base_url = "https://api.telegram.org/bot"
 
         file_base_url = self.config.get(
-            "telegram_file_base_url", "https://api.telegram.org/file/bot"
+            "telegram_file_base_url",
+            "https://api.telegram.org/file/bot",
         )
         if not file_base_url:
             file_base_url = "https://api.telegram.org/file/bot"
@@ -59,10 +64,12 @@ class TelegramPlatformAdapter(Platform):
         self.base_url = base_url
 
         self.enable_command_register = self.config.get(
-            "telegram_command_register", True
+            "telegram_command_register",
+            True,
         )
         self.enable_command_refresh = self.config.get(
-            "telegram_command_auto_refresh", True
+            "telegram_command_auto_refresh",
+            True,
         )
         self.last_command_hash = None
 
@@ -85,19 +92,22 @@ class TelegramPlatformAdapter(Platform):
 
     @override
     async def send_by_session(
-        self, session: MessageSesion, message_chain: MessageChain
+        self,
+        session: MessageSesion,
+        message_chain: MessageChain,
     ):
         from_username = session.session_id
         await TelegramPlatformEvent.send_with_client(
-            self.client, message_chain, from_username
+            self.client,
+            message_chain,
+            from_username,
         )
         await super().send_by_session(session, message_chain)
 
     @override
     def meta(self) -> PlatformMetadata:
-        return PlatformMetadata(
-            name="telegram", description="telegram 适配器", id=self.config.get("id")
-        )
+        id_ = self.config.get("id") or "telegram"
+        return PlatformMetadata(name="telegram", description="telegram 适配器", id=id_)
 
     @override
     async def run(self):
@@ -117,6 +127,10 @@ class TelegramPlatformAdapter(Platform):
             )
             self.scheduler.start()
 
+        if not self.application.updater:
+            logger.error("Telegram Updater is not initialized. Cannot start polling.")
+            return
+
         queue = self.application.updater.start_polling()
         logger.info("Telegram Platform Adapter is running.")
         await queue
@@ -128,7 +142,7 @@ class TelegramPlatformAdapter(Platform):
 
             if commands:
                 current_hash = hash(
-                    tuple((cmd.command, cmd.description) for cmd in commands)
+                    tuple((cmd.command, cmd.description) for cmd in commands),
                 )
                 if current_hash == self.last_command_hash:
                     return
@@ -150,7 +164,9 @@ class TelegramPlatformAdapter(Platform):
                 continue
             for event_filter in handler_metadata.event_filters:
                 cmd_info = self._extract_command_info(
-                    event_filter, handler_metadata, skip_commands
+                    event_filter,
+                    handler_metadata,
+                    skip_commands,
                 )
                 if cmd_info:
                     cmd_name, description = cmd_info
@@ -161,7 +177,9 @@ class TelegramPlatformAdapter(Platform):
 
     @staticmethod
     def _extract_command_info(
-        event_filter, handler_metadata, skip_commands: set
+        event_filter,
+        handler_metadata,
+        skip_commands: set,
     ) -> tuple[str, str] | None:
         """从事件过滤器中提取指令信息"""
         cmd_name = None
@@ -194,8 +212,14 @@ class TelegramPlatformAdapter(Platform):
         return cmd_name, description
 
     async def start(self, update: Update, context: ContextTypes.DEFAULT_TYPE):
+        if not update.effective_chat:
+            logger.warning(
+                "Received a start command without an effective chat, skipping /start reply.",
+            )
+            return
         await context.bot.send_message(
-            chat_id=update.effective_chat.id, text=self.config["start_message"]
+            chat_id=update.effective_chat.id,
+            text=self.config["start_message"],
         )
 
     async def message_handler(self, update: Update, context: ContextTypes.DEFAULT_TYPE):
@@ -205,16 +229,24 @@ class TelegramPlatformAdapter(Platform):
             await self.handle_msg(abm)
 
     async def convert_message(
-        self, update: Update, context: ContextTypes.DEFAULT_TYPE, get_reply=True
-    ) -> AstrBotMessage:
+        self,
+        update: Update,
+        context: ContextTypes.DEFAULT_TYPE,
+        get_reply=True,
+    ) -> AstrBotMessage | None:
         """转换 Telegram 的消息对象为 AstrBotMessage 对象。
 
         @param update: Telegram 的 Update 对象。
         @param context: Telegram 的 Context 对象。
         @param get_reply: 是否获取回复消息。这个参数是为了防止多个回复嵌套。
         """
+        if not update.message:
+            logger.warning("Received an update without a message.")
+            return None
+
         message = AstrBotMessage()
         message.session_id = str(update.message.chat.id)
+
         # 获得是群聊还是私聊
         if update.message.chat.type == ChatType.PRIVATE:
             message.type = MessageType.FRIEND_MESSAGE
@@ -225,10 +257,14 @@ class TelegramPlatformAdapter(Platform):
                 # Topic Group
                 message.group_id += "#" + str(update.message.message_thread_id)
                 message.session_id = message.group_id
-
         message.message_id = str(update.message.message_id)
+        _from_user = update.message.from_user
+        if not _from_user:
+            logger.warning("[Telegram] Received a message without a from_user.")
+            return None
         message.sender = MessageMember(
-            str(update.message.from_user.id), update.message.from_user.username
+            str(_from_user.id),
+            _from_user.username or "Unknown",
         )
         message.self_id = str(context.bot.username)
         message.raw_message = update
@@ -247,22 +283,32 @@ class TelegramPlatformAdapter(Platform):
             )
             reply_abm = await self.convert_message(reply_update, context, False)
 
-            message.message.append(
-                Comp.Reply(
-                    id=reply_abm.message_id,
-                    chain=reply_abm.message,
-                    sender_id=reply_abm.sender.user_id,
-                    sender_nickname=reply_abm.sender.nickname,
-                    time=reply_abm.timestamp,
-                    message_str=reply_abm.message_str,
-                    text=reply_abm.message_str,
-                    qq=reply_abm.sender.user_id,
+            if reply_abm:
+                message.message.append(
+                    Comp.Reply(
+                        id=reply_abm.message_id,
+                        chain=reply_abm.message,
+                        sender_id=reply_abm.sender.user_id,
+                        sender_nickname=reply_abm.sender.nickname,
+                        time=reply_abm.timestamp,
+                        message_str=reply_abm.message_str,
+                        text=reply_abm.message_str,
+                        qq=reply_abm.sender.user_id,
+                    ),
                 )
-            )
 
         if update.message.text:
             # 处理文本消息
             plain_text = update.message.text
+            if (
+                message.type == MessageType.GROUP_MESSAGE
+                and update.message
+                and update.message.reply_to_message
+                and update.message.reply_to_message.from_user
+                and update.message.reply_to_message.from_user.id == context.bot.id
+            ):
+                plain_text2 = f"/@{context.bot.username} " + plain_text
+                plain_text = plain_text2
 
             # 群聊场景命令特殊处理
             if plain_text.startswith("/"):
@@ -294,7 +340,7 @@ class TelegramPlatformAdapter(Platform):
 
             if message.message_str.strip() == "/start":
                 await self.start(update, context)
-                return
+                return None
 
         elif update.message.voice:
             file = await update.message.voice.get_file()
@@ -328,15 +374,25 @@ class TelegramPlatformAdapter(Platform):
 
         elif update.message.document:
             file = await update.message.document.get_file()
-            message.message = [
-                Comp.File(file=file.file_path, name=update.message.document.file_name),
-            ]
+            file_name = update.message.document.file_name or uuid.uuid4().hex
+            file_path = file.file_path
+            if file_path is None:
+                logger.warning(
+                    f"Telegram document file_path is None, cannot save the file {file_name}.",
+                )
+            else:
+                message.message.append(Comp.File(file=file_path, name=file_name))
 
         elif update.message.video:
             file = await update.message.video.get_file()
-            message.message = [
-                Comp.Video(file=file.file_path, path=file.file_path),
-            ]
+            file_name = update.message.video.file_name or uuid.uuid4().hex
+            file_path = file.file_path
+            if file_path is None:
+                logger.warning(
+                    f"Telegram video file_path is None, cannot save the file {file_name}.",
+                )
+            else:
+                message.message.append(Comp.Video(file=file_path, path=file.file_path))
 
         return message
 
