@@ -34,7 +34,9 @@ export type ThemeTypes = {
     primary200?: string;
     secondary200?: string;
     codeBg?: string;
+    preBg?: string;
     code?: string;
     chatMessageBubble?: string;
+    mcpCardBg?: string;
   };
 };
