@@ -39,7 +39,7 @@ export default defineConfig({
     port: 3000,
     proxy: {
       '/api': {
-        target: 'http://localhost:6185/',
+        target: 'http://127.0.0.1:6185/',
         changeOrigin: true,
       }
     }
