@@ -1,17 +1,18 @@
-import os
-import asyncio
-import sys
-import mimetypes
 import argparse
-from astrbot.core.initial_loader import InitialLoader
-from astrbot.core import db_helper
-from astrbot.core import logger, LogManager, LogBroker
-from astrbot.core.config.default import VERSION
-from astrbot.core.utils.io import download_dashboard, get_dashboard_version
-from astrbot.core.utils.astrbot_path import get_astrbot_data_path
+import asyncio
+import mimetypes
+import os
+import sys
+from pathlib import Path
 
-# add parent path to sys.path
-sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
+from astrbot.core import LogBroker, LogManager, db_helper, logger
+from astrbot.core.config.default import VERSION
+from astrbot.core.initial_loader import InitialLoader
+from astrbot.core.utils.astrbot_path import get_astrbot_data_path
+from astrbot.core.utils.io import download_dashboard, get_dashboard_version
+
+# 将父目录添加到 sys.path
+sys.path.append(Path(__file__).parent.as_posix())
 
 logo_tmpl = r"""
      ___           _______.___________..______      .______     ______   .___________.
@@ -33,7 +34,7 @@ def check_env():
     os.makedirs("data/plugins", exist_ok=True)
     os.makedirs("data/temp", exist_ok=True)
 
-    # workaround for issue #181
+    # 针对问题 #181 的临时解决方案
     mimetypes.add_type("text/javascript", ".js")
     mimetypes.add_type("text/javascript", ".mjs")
     mimetypes.add_type("application/json", ".json")
@@ -46,24 +47,23 @@ async def check_dashboard_files(webui_dir: str | None = None):
         if os.path.exists(webui_dir):
             logger.info(f"使用指定的 WebUI 目录: {webui_dir}")
             return webui_dir
-        else:
-            logger.warning(f"指定的 WebUI 目录 {webui_dir} 不存在，将使用默认逻辑。")
+        logger.warning(f"指定的 WebUI 目录 {webui_dir} 不存在，将使用默认逻辑。")
 
     data_dist_path = os.path.join(get_astrbot_data_path(), "dist")
     if os.path.exists(data_dist_path):
         v = await get_dashboard_version()
         if v is not None:
-            # has file
+            # 存在文件
             if v == f"v{VERSION}":
                 logger.info("WebUI 版本已是最新。")
             else:
                 logger.warning(
-                    f"检测到 WebUI 版本 ({v}) 与当前 AstrBot 版本 (v{VERSION}) 不符。"
+                    f"检测到 WebUI 版本 ({v}) 与当前 AstrBot 版本 (v{VERSION}) 不符。",
                 )
         return data_dist_path
 
     logger.info(
-        "开始下载管理面板文件...高峰期（晚上）可能导致较慢的速度。如多次下载失败，请前往 https://github.com/Soulter/AstrBot/releases/latest 下载 dist.zip，并将其中的 dist 文件夹解压至 data 目录下。"
+        "开始下载管理面板文件...高峰期（晚上）可能导致较慢的速度。如多次下载失败，请前往 https://github.com/AstrBotDevs/AstrBot/releases/latest 下载 dist.zip，并将其中的 dist 文件夹解压至 data 目录下。",
     )
 
     try:
@@ -79,22 +79,25 @@ async def check_dashboard_files(webui_dir: str | None = None):
 if __name__ == "__main__":
     parser = argparse.ArgumentParser(description="AstrBot")
     parser.add_argument(
-        "--webui-dir", type=str, help="指定 WebUI 静态文件目录路径", default=None
+        "--webui-dir",
+        type=str,
+        help="指定 WebUI 静态文件目录路径",
+        default=None,
     )
     args = parser.parse_args()
 
     check_env()
 
-    # start log broker
+    # 启动日志代理
     log_broker = LogBroker()
     LogManager.set_queue_handler(logger, log_broker)
 
-    # check dashboard files
+    # 检查仪表板文件
     webui_dir = asyncio.run(check_dashboard_files(args.webui_dir))
 
     db = db_helper
 
-    # print logo
+    # 打印 logo
     logger.info(logo_tmpl)
 
     core_lifecycle = InitialLoader(db, log_broker)
